@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_indexFrameContainer.php 4095 2011-05-03 04:51:22Z fishbone $
+ * @version    SVN: $Id: admin_indexFrameContainer.php 4297 2011-09-06 03:00:32Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseFrameContainer.php');
@@ -50,16 +50,25 @@ class admin_indexFrameContainer extends BaseFrameContainer
 					$cmd == M3_REQUEST_CMD_SHOW_POSITION_WITH_WIDGET ||		// 表示位置を表示するとき(ウィジェット付き)
 					$cmd == M3_REQUEST_CMD_SHOW_WIDGET ||		// ウィジェットの単体表示
 					$cmd == M3_REQUEST_CMD_DO_WIDGET ||		// ウィジェット単体実行
-					$cmd == M3_REQUEST_CMD_CONFIG_WIDGET ||	// ウィジェットの設定
+//					$cmd == M3_REQUEST_CMD_CONFIG_WIDGET ||		// ウィジェットの設定
 					$cmd == M3_REQUEST_CMD_GET_WIDGET_INFO ||	// ウィジェット各種情報取得(AJAX用)
 					$cmd == M3_REQUEST_CMD_SHOW_PHPINFO){	// phpinfoの表示
 			// 管理者権限がなければ実行できない
-			//if ($gEnvManager->isSystemAdmin()){
-			if ($this->gEnv->isSystemManageUser()){	// システム運用可能ユーザかどうか
+			if ($gEnvManager->isSystemAdmin()){
+			//if ($this->gEnv->isSystemManageUser()){	// システム運用可能ユーザかどうか
 				$ret = true;
 			} else {
 				// クッキーがないため権限を識別できない場合は、管理者キーをチェックする
-				$ret = $gAccessManager->isValidAdminKey($request);
+				$ret = $gAccessManager->isValidAdminKey();
+			}
+		} else if ($cmd == M3_REQUEST_CMD_CONFIG_WIDGET){		// ウィジェットの設定
+			if ($this->gEnv->isSystemManageUser()){	// システム運用可能ユーザかどうか
+				// システム運用者の場合はアクセス可能なウィジェットをチェック
+				$widgetId = $request->trimValueOf(M3_REQUEST_PARAM_WIDGET_ID);
+				$ret = $gEnvManager->canUseWidgetAdmin($widgetId);
+			} else {
+				// クッキーがないため権限を識別できない場合は、管理者キーをチェックする
+				$ret = $gAccessManager->isValidAdminKey();
 			}
 		}
 
