@@ -86,6 +86,7 @@ CREATE TABLE _operation_log (
     ol_link              TEXT                                         NOT NULL,      -- リンク先
     ol_search_option     TEXT                                         NOT NULL,      -- 検索用補助データ
     ol_checked           BOOLEAN        DEFAULT false                 NOT NULL,      -- メッセージ確認状況
+    ol_show_top          BOOLEAN        DEFAULT false                 NOT NULL,      -- メッセージをトップ表示するかどうか
     ol_widget_id         VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 実行ウィジェットID(ファイル名)
     ol_method            TEXT                                         NOT NULL,      -- 実行メソッド
     ol_access_log_serial INT            DEFAULT 0                     NOT NULL,      -- アクセスログシリアル番号
@@ -199,6 +200,7 @@ CREATE TABLE _addons (
     ao_description       VARCHAR(60)    DEFAULT ''                    NOT NULL,      -- 説明
     ao_index             INT            DEFAULT 0                     NOT NULL,      -- ソート用
     ao_autoload          BOOLEAN        DEFAULT true                  NOT NULL,      -- システム起動時の自動読み込み
+    ao_opelog_hook       BOOLEAN        DEFAULT false                 NOT NULL,      -- 運用ログイベントフックがあるかどうか
     PRIMARY KEY          (ao_id)
 ) TYPE=innodb;
 
@@ -216,6 +218,7 @@ CREATE TABLE _login_user (
     lu_user_type_option  TEXT                                         NOT NULL,      -- ユーザタイプオプション(「ウィジェットID=ユーザタイプ」形式の前後「;」区切りで複数指定可)
     lu_assign            TEXT                                         NOT NULL,      -- ログイン可能な機能(2バイト文字カンマ区切り、sy=システム管理機能、ec=EC、bg=ブログ、bs=BBS、rv=予約, wk=Wiki)
     lu_admin_widget      TEXT                                         NOT NULL,      -- システム運営者が管理可能なウィジェット(「,」区切りで複数指定可)
+    lu_default_admin_url TEXT                                         NOT NULL,      -- デフォルトの管理画面のURL(「?」以降)
     lu_user_status       SMALLINT       DEFAULT 0                     NOT NULL,      -- ユーザの状態
     lu_avatar            VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- アバターファイル名
     lu_email             VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- Eメールアドレス
@@ -271,6 +274,27 @@ CREATE TABLE _login_user_info (
     UNIQUE               (li_id,        li_history_index)
 ) TYPE=innodb;
 
+-- 自動ログインマスター
+DROP TABLE IF EXISTS _auto_login;
+CREATE TABLE _auto_login (
+    ag_id                CHAR(32)       DEFAULT ''                    NOT NULL,      -- 自動ログインキー
+    ag_user_id           INT            DEFAULT 0                     NOT NULL,      -- ログインユーザID
+    ag_client_id         VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- PCの場合はアクセス管理用クッキー値。携帯の場合は端末ID「XX-xxxxxx」(XX=キャリアDC,AU,SB、xxxxxx=端末ID)。
+    ag_index             INT            DEFAULT 0                     NOT NULL,      -- インデックス番号(0～)
+
+    ag_path              VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- アクセスポイントパス
+    ag_expire_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 有効期限
+    ag_access_log_serial INT            DEFAULT 0                     NOT NULL,      -- 登録時アクセスログシリアル番号
+
+    ag_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
+    ag_create_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード作成日時
+    ag_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
+    ag_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
+    ag_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
+    PRIMARY KEY          (ag_id),
+    UNIQUE               (ag_user_id,   ag_client_id, ag_index)
+) TYPE=innodb;
+
 -- ユーザグループマスター
 DROP TABLE IF EXISTS _user_group;
 CREATE TABLE _user_group (
@@ -436,6 +460,7 @@ CREATE TABLE _attach_file (
     af_desc              TEXT                                         NOT NULL,      -- 説明
     af_file_type         VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- ファイルタイプ
     af_original_filename VARCHAR(256)   DEFAULT ''                    NOT NULL,      -- 元のファイル名
+    af_original_url      TEXT                                         NOT NULL,      -- 取得元URL
     af_file_size         INT            DEFAULT 0                     NOT NULL,      -- ファイルサイズ(バイト)
     af_file_dt           TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- ファイル作成日時
     af_file_deleted_dt   TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- ファイル削除日時
@@ -446,6 +471,18 @@ CREATE TABLE _attach_file (
     UNIQUE               (af_content_type,      af_content_id,        af_content_serial, af_index, af_client_id)
 ) TYPE=innodb;
 
+-- オプションコンテンツパラメータマスター
+DROP TABLE IF EXISTS _option_content_param;
+CREATE TABLE _option_content_param (
+    oc_page_id           VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- ページID
+    oc_id                VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- URLパラメータ
+
+    oc_name              VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- コンテンツ名称
+    oc_widget_id         VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 実行ウィジェットID(ファイル名)
+    oc_sort_order        INT            DEFAULT 0                     NOT NULL,      -- ソート順
+    PRIMARY KEY          (oc_page_id,   oc_id)
+) TYPE=innodb;
+
 -- コンテンツアクセス権マスター
 DROP TABLE IF EXISTS _content_access;
 CREATE TABLE _content_access (
@@ -501,11 +538,13 @@ CREATE TABLE _templates (
     tm_type              INT            DEFAULT 0                     NOT NULL,      -- テンプレート種別(0=デフォルトテンプレート(Joomla!v1.0),1=Joomla!v1.5,2=Joomla!v2.5,10=Bootstrap v3.0,20=jQuery Mobile)
     tm_device_type       INT            DEFAULT 0                     NOT NULL,      -- 端末タイプ(0=PC、1=携帯、2=スマートフォン)
     tm_language          TEXT                                         NOT NULL,      -- 対応言語ID(「,」区切りで複数指定可)
+    tm_version           VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- テンプレートバージョン文字列
     tm_name              VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- テンプレート名
     tm_description       VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- 説明
     tm_url               TEXT                                         NOT NULL,      -- 取得先URL
     tm_joomla_params     TEXT                                         NOT NULL,      -- joomla!用パラメータ
     tm_mobile            BOOLEAN        DEFAULT false                 NOT NULL,      -- 携帯対応かどうか
+    tm_use_bootstrap     BOOLEAN        DEFAULT false                 NOT NULL,      -- Bootstrapを使用するかどうか
     tm_available         BOOLEAN        DEFAULT true                  NOT NULL,      -- メニューから選択可能かどうか
     tm_clean_type        INT            DEFAULT 0                     NOT NULL,      -- 出力のクリーン処理(0=処理なし,0以外=クリーン処理実行)
     
@@ -528,14 +567,22 @@ CREATE TABLE _widgets (
     wd_language          TEXT                                         NOT NULL,      -- 対応言語ID(「,」区切りで複数指定可)
     wd_name              VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- ウィジェット名称
     wd_type              VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- ウィジェット種別(menu=メニュー,content=コンテンツ編集)
+    wd_type_option       VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- ウィジェット種別オプション(nav=ナビゲーションメニュー)
+    wd_category_id       VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 所属カテゴリー
     wd_content_type      VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- 必要とするページのコンテンツ種別
+    wd_content_name      TEXT                                         NOT NULL,      -- コンテンツ名称(管理画面メニュー表示用)
+    wd_content_info      VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- コンテンツ情報
     wd_device_type       INT            DEFAULT 0                     NOT NULL,      -- 端末タイプ(0=PC、1=携帯、2=スマートフォン)
     wd_version           VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- バージョン文字列
+    wd_latest_version    VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- 最新バージョンのバージョン文字列
+    wd_required_version  VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- 動作に必要なシステムバージョン
     wd_fingerprint       CHAR(32)       DEFAULT ''                    NOT NULL,      -- ソースコードレベルでウィジェットを識別するためのID
     wd_group_id          VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- ウィジェットグループ(管理用)
     wd_compatible_id     VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 互換ウィジェットID
     wd_parent_id         VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 親ウィジェットID(ファイル名)
+    wd_content_widget_id VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- コンテンツ編集用のウィジェット
     wd_joomla_class      VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- Joomla!テンプレート用のクラス名
+    wd_template_type     TEXT                                         NOT NULL,      -- 対応するテンプレートタイプ(「,」区切りで指定。値=bootstrap,jquerymobile)
     wd_suffix            VARCHAR(4)     DEFAULT ''                    NOT NULL,      -- HTMLタグのクラス名に付けるサフィックス文字列
     wd_params            VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- 各種パラメータ
     wd_author            VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- 作者名
@@ -572,6 +619,7 @@ CREATE TABLE _widgets (
     wd_initialized       BOOLEAN        DEFAULT false                 NOT NULL,      -- 初期化完了かどうか
     wd_use_cache         BOOLEAN        DEFAULT false                 NOT NULL,      -- キャッシュ機能を使用するかどうか
     wd_has_rss           BOOLEAN        DEFAULT false                 NOT NULL,      -- RSS機能があるかどうか
+    wd_priority          INT            DEFAULT 0                     NOT NULL,      -- 優先度
     wd_sort_order        INT            DEFAULT 0                     NOT NULL,      -- ソート順
 --    wd_cache_interval    INT            DEFAULT 0                     NOT NULL,      -- キャッシュの更新時間(分)
     wd_launch_index      INT            DEFAULT 0                     NOT NULL,      -- 遅延実行制御が必要な場合の実行順(0=未設定、0以上=実行順)
@@ -596,6 +644,26 @@ CREATE TABLE _widgets (
     UNIQUE               (wd_id,        wd_history_index)
 ) TYPE=innodb;
 
+-- ウィジェットカテゴリマスター
+DROP TABLE IF EXISTS _widget_category;
+CREATE TABLE _widget_category (
+    wt_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    wt_id                VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- カテゴリID
+    wt_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
+
+    wt_name              VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- カテゴリ名称
+    wt_sort_order        INT            DEFAULT 0                     NOT NULL,      -- ソート用
+    wt_visible           BOOLEAN        DEFAULT true                  NOT NULL,      -- 表示するかどうか
+
+    wt_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
+    wt_create_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード作成日時
+    wt_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
+    wt_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
+    wt_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
+    PRIMARY KEY          (wt_serial),
+    UNIQUE               (wt_id,        wt_history_index)
+) TYPE=innodb;
+
 -- ウィジェットパラメータマスター
 DROP TABLE IF EXISTS _widget_param;
 CREATE TABLE _widget_param (
@@ -711,6 +779,7 @@ CREATE TABLE _page_id (
     pg_active            BOOLEAN        DEFAULT true                  NOT NULL,      -- 有効かどうか
     pg_visible           BOOLEAN        DEFAULT true                  NOT NULL,      -- 表示可能かどうか
     pg_editable          BOOLEAN        DEFAULT true                  NOT NULL,      -- データ編集可能かどうか
+    pg_available         BOOLEAN        DEFAULT true                  NOT NULL,      -- メニューから選択可能かどうか
     pg_admin_menu        BOOLEAN        DEFAULT false                 NOT NULL,      -- 管理メニューを表示するかどうか(ページID種別がアクセスポイント時。初期値。)
     pg_analytics         BOOLEAN        DEFAULT false                 NOT NULL,      -- アクセス解析対象かどうか(ページID種別がアクセスポイント時)
     PRIMARY KEY  (pg_id, pg_type)
