@@ -27,7 +27,17 @@ INSERT INTO content_config
 ('',           'output_head',      '0', 'HTMLヘッダ出力', 2),
 ('smartphone', 'output_head',      '0', 'HTMLヘッダ出力', 2),
 ('',           'head_view_detail', '<meta property="og:type" content="article" /><meta property="og:title" content="[#CT_TITLE#]" /><meta property="og:url" content="[#CT_URL#]" /><meta property="og:image" content="[#CT_IMAGE#]" /><meta property="og:description" content="[#CT_DESCRIPTION#]" /><meta property="og:site_name" content="[#SITE_NAME#]" />', 'HTMLヘッダ(詳細表示)',               3),
-('smartphone', 'head_view_detail', '<meta property="og:type" content="article" /><meta property="og:title" content="[#CT_TITLE#]" /><meta property="og:url" content="[#CT_URL#]" /><meta property="og:image" content="[#CT_IMAGE#]" /><meta property="og:description" content="[#CT_DESCRIPTION#]" /><meta property="og:site_name" content="[#SITE_NAME#]" />', 'HTMLヘッダ(詳細表示)',               3);
+('smartphone', 'head_view_detail', '<meta property="og:type" content="article" /><meta property="og:title" content="[#CT_TITLE#]" /><meta property="og:url" content="[#CT_URL#]" /><meta property="og:image" content="[#CT_IMAGE#]" /><meta property="og:description" content="[#CT_DESCRIPTION#]" /><meta property="og:site_name" content="[#SITE_NAME#]" />', 'HTMLヘッダ(詳細表示)',               3),
+('',           'use_jquery',      '0', 'jQueryスクリプト作成', 0),
+('smartphone', 'use_jquery',      '0', 'jQueryスクリプト作成', 0),
+('',           'use_content_template',      '0', 'コンテンツ単位のテンプレート設定', 0);
+
+-- 新着情報設定マスター
+INSERT INTO news_config
+(nc_id,                  nc_value,    nc_name,                              nc_index) VALUES
+('default_message',   '「[#TITLE#]」を追加しました', 'デフォルトメッセージ',               1),
+('date_format',       'n月j日', '日時フォーマット',               1),
+('layout_list_item',  '[#DATE#] [#MESSAGE#][#MARK#]', 'リスト項目レイアウト',               1);
 
 -- Wiki設定マスター
 INSERT INTO wiki_config (wg_id,        wg_value,     wg_name,                 wg_index)
@@ -136,6 +146,17 @@ VALUES                       (0,            true,     1,               6,
 INSERT INTO reserve_calendar (ra_config_id, ra_usual, ra_specify_type, ra_day_attribute, ra_start_time, ra_end_time, ra_available)
 VALUES                       (0,            true,     1,               7,                900,           1200,        true);
 
+-- カレンダー初期データ
+INSERT INTO time_period
+(to_date_type_id, to_index, to_name, to_start_time, to_minute) VALUES
+(1, 0, '午前', '09:00:00', 180),
+(1, 1, '午後', '13:00:00', 240),
+(2, 0, '午前', '09:00:00', 180);
+INSERT INTO date_type
+(dt_id, dt_name, dt_sort_order) VALUES
+(1, '営業日(終日)', 1),
+(2, '営業日(午前のみ)', 2);
+
 -- テーブルのバージョン
 DELETE FROM _version WHERE vs_id = 'standard_table';
 INSERT INTO _version (vs_id,                         vs_value, vs_name)
@@ -173,19 +194,21 @@ VALUES                 ('send_tmp_password', 'ja',           '仮パスワード
 -- テンプレート情報
 TRUNCATE TABLE _templates;
 INSERT INTO _templates
-(tm_id,                           tm_name,                         tm_type, tm_device_type, tm_mobile, tm_available, tm_clean_type, tm_create_dt) VALUES
-('_admin2',                       '_admin2',                       1,       0,              false,     false,        0,             now()),
-('_admin3',                       '_admin3',                       2,       0,              false,     false,        0,             now()),
-('_system',                       '_system',                       1,       0,              false,     false,        0,             now()),
-('_layout',                       '_layout',                       1,       0,              false,     false,        0,             now()),
-('art41_sample1',                 'art41_sample1',                 2,       0,              false,     true,         0,             now()),
-('art41_sample2',                 'art41_sample2',                 2,       0,              false,     true,         0,             now()),
-('m/default',                     'm/default',                     0,       1,              true,      true,         0,             now()),
-('m/smallfont',                   'm/smallfont',                   0,       1,              true,      true,         0,             now()),
-('s/default_simple',              's/default_simple',              1,       2,              false,     true,         0,             now()),
-('s/default_jquery',              's/default_jquery',              1,       2,              false,     true,         0,             now()),
-('s/default_jquery13',           's/default_jquery13',             1,       2,              false,     true,         0,             now()),
-('s/art42_sample2',               's/art42_sample2',               1,       2,              false,     true,         0,             now());
+(tm_id,                           tm_name,                         tm_type, tm_device_type, tm_mobile, tm_use_bootstrap, tm_available, tm_clean_type, tm_create_dt) VALUES
+('_admin4',                       '_admin4',                       2,       0,              false,     true,             false,        0,             now()),
+('_system',                       '_system',                       1,       0,              false,     false,            false,        0,             now()),
+('_layout',                       '_layout',                       1,       0,              false,     false,            false,        0,             now()),
+('art41_sample1',                 'art41_sample1',                 2,       0,              false,     false,            true,         0,             now()),
+('art41_sample2',                 'art41_sample2',                 2,       0,              false,     false,            true,         0,             now()),
+('bootstrap_yeti',                'bootstrap_yeti',                10,      0,              false,     true,             true,         0,             now()),
+('bootstrap_cerulean',            'bootstrap_cerulean',            10,      0,              false,     true,             true,         0,             now()),
+('bootstrap_united',              'bootstrap_united',              10,      0,              false,     true,             true,         0,             now()),
+('m/default',                     'm/default',                     0,       1,              true,      false,            true,         0,             now()),
+('m/smallfont',                   'm/smallfont',                   0,       1,              true,      false,            true,         0,             now()),
+('s/default_simple',              's/default_simple',              1,       2,              false,     false,            true,         0,             now()),
+('s/default_jquery',              's/default_jquery',              1,       2,              false,     false,            true,         0,             now()),
+('s/default_jquery13',           's/default_jquery13',             1,       2,              false,     false,            true,         0,             now()),
+('s/art42_sample2',               's/art42_sample2',               1,       2,              false,     false,            true,         0,             now());
 
 -- メニューIDマスター
 INSERT INTO _menu_id
@@ -194,6 +217,7 @@ INSERT INTO _menu_id
 ('sub_menu1',   'サブメニュー1(PC用)',  '',             0,        '',      1),
 ('sub_menu2',   'サブメニュー2(PC用)',  '',             0,        '',      2),
 ('sub_menu3',   'サブメニュー3(PC用)',  '',             0,        '',      3),
+('m_main_menu', 'メインメニュー(携帯用)', '',             1,      '',        10),
 ('s_main_menu', 'メインメニュー(スマートフォン用)', '',             2,     '',         0);
 
 -- 基本テーブルの不要なデータを削除
@@ -318,6 +342,8 @@ INSERT INTO event_config
 ('comment_count',           '100',       '1投稿記事のコメント最大数',          4),
 ('comment_open_time',       '30',        'コメント投稿可能期間(日)',           5),
 ('top_contents',            '',          'トップ画面コンテンツ',               6),
+('msg_no_entry_in_future',  '今後のイベントはありません',         '予定イベントなし時メッセージ',                 0),
+('catagory_count',          '2', 'カテゴリー最大数', 0),
 ('m:entry_view_count',      '3',         '記事表示数(携帯)',                   7),
 ('m:entry_view_order',      '1',         '記事表示順(携帯)',                   8),
 ('m:top_contents',          '',          'トップ画面コンテンツ(携帯)',         9);
@@ -350,7 +376,18 @@ INSERT INTO photo_config
 ('s:photo_title_short_length',  '7',                '画像タイトル(略式)文字数',         202),
 ('s:photo_list_sort_key', 'index',            '画像一覧のソートキー',         203),
 ('s:default_image_size',      '320',              '公開画像デフォルトサイズ',               204),
-('s:default_thumbnail_size',  '128',              'サムネール画像デフォルトサイズ',         205);
+('s:default_thumbnail_size',  '128',              'サムネール画像デフォルトサイズ',         205),
+('html_photo_description',  '0',                'HTML形式の画像情報(説明)',         0),
+('use_photo_date',        '1',                '画像情報(撮影日)を使用',         0),
+('use_photo_location',       '1',                '画像情報(撮影場所)を使用',         0),
+('use_photo_camera',      '1',                '画像情報(カメラ)を使用',         0),
+('use_photo_description', '1',                '画像情報(説明)を使用',         0),
+('use_photo_keyword',     '1',                '画像情報(検索キーワード)を使用',         0),
+('use_photo_category',    '1',                '画像情報(カテゴリー)を使用',         0),
+('use_photo_rate',    '1',                '画像情報(評価)を使用',         0),
+('layout_view_detail',   '<table class="photo_info"><caption>画像情報</caption><tbody><tr><th>ID</th><td>[#CT_ID#]</td></tr><tr><th>タイトル</th><td>[#CT_TITLE#]&nbsp;[#PERMALINK#]</td></tr><tr><th>撮影者</th><td>[#CT_AUTHOR#]</td></tr><tr><th>撮影日</th><td>[#CT_DATE#]</td></tr><tr><th>場所</th><td>[#CT_LOCATION#]</td></tr><tr><th>カメラ</th><td>[#CT_CAMERA#]</td></tr><tr><th>説明</th><td>[#CT_DESCRIPTION#]</td></tr><tr><th>カテゴリー</th><td>[#CT_CATEGORY#]</td></tr><tr><th>キーワード</th><td>[#CT_KEYWORD#]</td></tr><tr><th>評価</th><td>[#RATE#]</td></tr></tbody></table>', 'レイアウト(詳細表示)',               0),
+('output_head',      '0', 'HTMLヘッダ出力', 0),
+('head_view_detail',   '<meta property="og:type" content="article" /><meta property="og:title" content="[#CT_TITLE#]" /><meta property="og:url" content="[#CT_URL#]" /><meta property="og:image" content="[#CT_IMAGE#]" /><meta property="og:description" content="[#CT_SUMMARY#]" /><meta property="og:site_name" content="[#SITE_NAME#]" />', 'ヘッダ出力(詳細表示)',               0);
 
 -- --------------------------------------------------------------------------------------------------
 -- 携帯クイズ王ウィジェット用
