@@ -122,9 +122,8 @@ CKEDITOR.editorConfig = function(config){
 	// ツールバーの設定
 	if (M3_USE_GOOGLEMAPS){			// GoogleMapsを使用する場合
 		config.toolbar_Full = [
-			{ name: 'tools', items: [ 'Maximize', 'ShowBlocks' ] },
-			{ name: 'document', items: [ 'Source', 'Templates' ] },
-			{ name: 'clipboard', items: [ 'Cut', 'Copy', 'Paste', 'PasteText', 'PasteFromWord', '-', 'Undo', 'Redo' ] },
+			{ name: 'tools', items: [ 'Maximize', 'ShowBlocks', 'Source' ] },
+			{ name: 'clipboard', items: [ 'Templates', '-', 'Cut', 'Copy', 'Paste', 'PasteText', 'PasteFromWord', '-', 'Undo', 'Redo' ] },
 			{ name: 'editing', items : [ 'Find','Replace','-','SelectAll' ] },
 			{ name: 'insert', items: [ 'Image', 'Flash', 'YouTube', 'Googlemaps', 'Table', 'HorizontalRule' ] },
 			{ name: 'colors', items : [ 'TextColor', 'BGColor' ] },
@@ -139,9 +138,8 @@ CKEDITOR.editorConfig = function(config){
 		];
 	} else {
 		config.toolbar_Full = [
-			{ name: 'tools', items: [ 'Maximize', 'ShowBlocks' ] },
-			{ name: 'document', items: [ 'Source', 'Templates' ] },
-			{ name: 'clipboard', items: [ 'Cut', 'Copy', 'Paste', 'PasteText', 'PasteFromWord', '-', 'Undo', 'Redo' ] },
+			{ name: 'tools', items: [ 'Maximize', 'ShowBlocks', 'Source' ] },
+			{ name: 'clipboard', items: [ 'Templates', '-', 'Cut', 'Copy', 'Paste', 'PasteText', 'PasteFromWord', '-', 'Undo', 'Redo' ] },
 			{ name: 'editing', items : [ 'Find','Replace','-','SelectAll' ] },
 			{ name: 'insert', items: [ 'Image', 'Flash', /*'YouTube', 'Googlemaps',*/ 'Table', 'HorizontalRule' ] },
 			{ name: 'colors', items : [ 'TextColor', 'BGColor' ] },
@@ -166,7 +164,7 @@ CKEDITOR.editorConfig = function(config){
 	config.stylesCombo_stylesSet = 'default';
 	
 	// メッセージの変更
-	config.image_previewText = '<strong>「サーバーブラウザー」ボタン</strong>をクリックすると画像ブラウザが立ち上がり、サムネール表示の画像をダブルクリックすると取得できます。画像をアップロードするには、画像ブラウザ上部の「アップロード」ボタンをクリックするか、画像ブラウザ上へ画像ファイルをドロップします。';
+	config.image_previewText = '<strong>「サーバブラウザ」ボタン</strong>をクリックすると画像ブラウザが立ち上がります。サムネール表示の画像をダブルクリックすると画像が取得できます。画像をアップロードするには、画像ブラウザ上部の「アップロード」ボタンをクリックするか、画像ブラウザ上へ画像ファイルをドロップします。';
 	
 	// 追加プラグインの設定
 //	config.extraPlugins = 'youtube,googlemaps';
@@ -176,6 +174,7 @@ CKEDITOR.editorConfig = function(config){
 	config.allowedContent = true;		// ACF(Advanced Content Filter)を使用しない。SCRIPT,IFRAMEタグ等許可。
 //	config.extraAllowedContent = 'iframe';
 //	config.autoGrow_maxHeight = 800;		// 指定サイズまで入力に合わせて拡大
+	config.protectedSource.push(/<i[^>]*><\/i>/g);	// iタグ許可
 	
 	// KCFinderの設定
 	if (!jQuery().elfinder){			// elFinderが使用できない場合
