@@ -185,30 +185,6 @@ function m3OpenImageFileBrowser(seturl_callback)
 		}
 	});
 }
-/**
- * 画像ファイルブラウザを表示(廃止予定)
- *
- * @return なし
- */
-function m3_openImageFileBrowser()
-{
-	var imageConnector = 'connectors/php/connector.php';
-	var imageBrowser = M3_ROOT_URL + '/scripts/fckeditor2.6.6/editor/plugins/FileBrowser_Thumbnail/browser.html?Type=Image&Lang=ja&Connector=' + imageConnector;
-	var sOptions = "toolbar=no,status=no,resizable=yes,dependent=yes,scrollbars=yes";
-	var screenWidth, screenHeight;
-	var width, height;
-	try
-	{
-		screenWidth	= screen.width;
-		screenHeight	= screen.height;
-	} catch (e){
-		screenWidth		= 800;
-		screenHeight	= 600;
-	}
-	width	= screenWidth * 0.7;
-	height	= screenHeight * 0.7;
-	window.open(imageBrowser, 'FCKBrowseWindow', sOptions + ",width=" + width + ",height=" + height);
-}
 /**
  * Flashファイルブラウザを表示
  *
@@ -240,30 +216,6 @@ function m3OpenFlashFileBrowser(seturl_callback)
 		}
 	});
 }
-/**
- * Flashファイルブラウザを表示(廃止予定)
- *
- * @return なし
- */
-function m3_openFlashFileBrowser()
-{
-	var imageConnector = 'connectors/php/connector.php';
-	var imageBrowser = M3_ROOT_URL + '/scripts/fckeditor2.6.6/editor/plugins/FileBrowser_Thumbnail/browser.html?Type=Flash&Lang=ja&Connector=' + imageConnector;
-	var sOptions = "toolbar=no,status=no,resizable=yes,dependent=yes,scrollbars=yes";
-	var screenWidth, screenHeight;
-	var width, height;
-	try
-	{
-		screenWidth	= screen.width;
-		screenHeight	= screen.height;
-	} catch (e){
-		screenWidth		= 800;
-		screenHeight	= 600;
-	}
-	width	= screenWidth * 0.7;
-	height	= screenHeight * 0.7;
-	window.open(imageBrowser, 'FCKBrowseWindow', sOptions + ",width=" + width + ",height=" + height);
-}
 /**
  * TextAreaをHTMLエディターに変更
  *
@@ -522,7 +474,15 @@ function m3CancelSafeContentEdit()
 function m3SetHelp()
 {
     $('span.m3help').cluetip({splitTitle: '|', cluezIndex: 2000});
-    if (jQuery().tooltip) $('[rel=m3help]').tooltip({ placement: 'top'});
+    if (jQuery().tooltip){
+/*		$('[rel=m3help]').each( function(){
+    		var place = $(this).data('placement');
+			if (!place) place = 'top';
+			$(this).tooltip({ placement: place });
+  		});*/
+		//$('[rel=m3help]').tooltip({ placement: 'top'});
+		$('[rel=m3help]').tooltip();
+	}
 }
 /**
  * ファイル選択ボタンを設定
@@ -549,8 +509,10 @@ function m3SetFileSelectButton()
 	    input.trigger('fileselect', [numFiles, label]);
 	});
 }
-/*
- * 初期処理
+/**
+ * 管理画面初期処理
+ *
+ * @return なし
  */
 $(function(){
 	//** jQuery Scroll to Top Control script- (c) Dynamic Drive DHTML code library: http://www.dynamicdrive.com.
@@ -558,7 +520,7 @@ $(function(){
 	//** v1.1 (April 7th, 09'):
 	//** 1) Adds ability to scroll to an absolute position (from top of page) or specific element on the page instead.
 	//** 2) Fixes scroll animation not working in Opera. 
-	var scrolltotop={
+	var scrolltotop = {
 		//startline: Integer. Number of pixels from top of doc scrollbar is scrolled before showing control
 		//scrollto: Keyword (Integer, or "Scroll_to_Element_ID"). How far to scroll document up when control is clicked on (0=top).
 		setting: {startline:100, scrollto: 0, scrollduration:1000, fadeduration:[500, 100]},
@@ -570,60 +532,62 @@ $(function(){
 
 		scrollup:function(){
 			if (!this.cssfixedsupport) //if control is positioned using JavaScript
-				this.$control.css({opacity:0}) //hide control immediately after clicking it
-			var dest=isNaN(this.setting.scrollto)? this.setting.scrollto : parseInt(this.setting.scrollto)
-			if (typeof dest=="string" && $('#'+dest).length==1) //check element set by string exists
-				dest=$('#'+dest).offset().top
+				this.$control.css({ opacity:0 }); //hide control immediately after clicking it
+			var dest = isNaN(this.setting.scrollto) ? this.setting.scrollto : parseInt(this.setting.scrollto);
+			if (typeof dest == "string" && $('#'+dest).length == 1) //check element set by string exists
+				dest=$('#'+dest).offset().top;
 			else
-				dest=0
-			this.$body.animate({scrollTop: dest}, this.setting.scrollduration);
+				dest=0;
+			this.$body.animate({ scrollTop: dest }, this.setting.scrollduration);
 		},
 
 		keepfixed:function(){
-			var $window=$(window)
-			var controlx=$window.scrollLeft() + $window.width() - this.$control.width() - this.controlattrs.offsetx
-			var controly=$window.scrollTop() + $window.height() - this.$control.height() - this.controlattrs.offsety
-			this.$control.css({left:controlx+'px', top:controly+'px'})
+			var $window=$(window);
+			var controlx=$window.scrollLeft() + $window.width() - this.$control.width() - this.controlattrs.offsetx;
+			var controly=$window.scrollTop() + $window.height() - this.$control.height() - this.controlattrs.offsety;
+			this.$control.css({ left:controlx+'px', top:controly+'px' });
 		},
 
 		togglecontrol:function(){
-			var scrolltop=$(window).scrollTop()
-			if (!this.cssfixedsupport)
-				this.keepfixed()
-			this.state.shouldvisible=(scrolltop>=this.setting.startline)? true : false
+			var scrolltop = $(window).scrollTop();
+			if (!this.cssfixedsupport) this.keepfixed();
+			this.state.shouldvisible = (scrolltop >= this.setting.startline) ? true : false;
 			if (this.state.shouldvisible && !this.state.isvisible){
-				this.$control.stop().animate({opacity:1}, this.setting.fadeduration[0])
-				this.state.isvisible=true
+				this.$control.stop().animate({ opacity:1 }, this.setting.fadeduration[0]);
+				this.state.isvisible = true;
 			}
-			else if (this.state.shouldvisible==false && this.state.isvisible){
-				this.$control.stop().animate({opacity:0}, this.setting.fadeduration[1])
-				this.state.isvisible=false
+			else if (this.state.shouldvisible == false && this.state.isvisible){
+				this.$control.stop().animate({ opacity:0 }, this.setting.fadeduration[1]);
+				this.state.isvisible = false;
 			}
 		},
 	
 		init:function(){
 			$(document).ready(function($){
-				var mainobj=scrolltotop
-				var iebrws=document.all
-				mainobj.cssfixedsupport=!iebrws || iebrws && document.compatMode=="CSS1Compat" && window.XMLHttpRequest //not IE or IE7+ browsers in standards mode
-				mainobj.$body=(window.opera)? (document.compatMode=="CSS1Compat"? $('html') : $('body')) : $('html,body')
-				mainobj.$control=$('<div id="topcontrol">'+mainobj.controlHTML+'</div>')
-					.css({position:mainobj.cssfixedsupport? 'fixed' : 'absolute', bottom:mainobj.controlattrs.offsety, right:mainobj.controlattrs.offsetx, opacity:0, cursor:'pointer'})
-					.attr({title:'先頭へスクロール'})
-					.click(function(){mainobj.scrollup(); return false})
-					.appendTo('body')
-				if (document.all && !window.XMLHttpRequest && mainobj.$control.text()!='') //loose check for IE6 and below, plus whether control contains any text
-					mainobj.$control.css({width:mainobj.$control.width()}) //IE6- seems to require an explicit width on a DIV containing text
-				mainobj.togglecontrol()
-				$('a[href="' + mainobj.anchorkeyword +'"]').click(function(){
-					mainobj.scrollup()
-					return false
-				})
+				var mainobj = scrolltotop;
+				var iebrws = document.all;
+				mainobj.cssfixedsupport = !iebrws || iebrws && document.compatMode == "CSS1Compat" && window.XMLHttpRequest; //not IE or IE7+ browsers in standards mode
+				mainobj.$body = (window.opera) ? (document.compatMode == "CSS1Compat" ? $('html') : $('body')) : $('html,body');
+				mainobj.$control = $('<div id="topcontrol">' + mainobj.controlHTML + '</div>')
+					.css({ position:mainobj.cssfixedsupport ? 'fixed' : 'absolute', bottom:mainobj.controlattrs.offsety, right:mainobj.controlattrs.offsetx, opacity:0, cursor:'pointer' })
+					.attr({ title:'先頭へスクロール' })
+					.click(function(){ mainobj.scrollup(); return false; })
+					.appendTo('body');
+				if (document.all && !window.XMLHttpRequest && mainobj.$control.text() != '') //loose check for IE6 and below, plus whether control contains any text
+					mainobj.$control.css({ width:mainobj.$control.width() }); //IE6- seems to require an explicit width on a DIV containing text
+				mainobj.togglecontrol();
+				$('a[href="' + mainobj.anchorkeyword + '"]').click(function(){
+					mainobj.scrollup();
+					return false;
+				});
 				$(window).bind('scroll resize', function(e){
-					mainobj.togglecontrol()
-				})
-			})
+					mainobj.togglecontrol();
+				});
+			});
 		}
 	}
-	scrolltotop.init()
+	scrolltotop.init();
+	
+	// ヘルプ作成
+	m3SetHelp();
 });
