@@ -100,8 +100,10 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 				$templateFile = 'index_old.tmpl.html';
 				break;
 			case 'BOOTSTRAP_NAV':		// Bootstrapナビゲーションメニュー
-				$this->cssFilePath[] = $this->getUrl($this->gEnv->getCurrentWidgetCssUrl() . self::DEFAULT_BOOTSTRAP_CSS_FILE);		// CSSファイル
 				$templateFile = 'index_bootstrap_nav.tmpl.html';
+				
+				// CSSファイルの追加
+				$this->cssFilePath[] = $this->getUrl($this->gEnv->getCurrentWidgetCssUrl() . self::DEFAULT_BOOTSTRAP_CSS_FILE);		// CSSファイル
 				break;
 			case 'BOOTSTRAP':		// Bootstrapメニュー
 				$templateFile = 'index_bootstrap.tmpl.html';
@@ -164,23 +166,28 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 			
 			// Bootstrap用のデータを埋め込む
 			if ($this->renderType == 'BOOTSTRAP_NAV'){
-				$this->tmpl->addVar("_widget", "site_url", $this->convertUrlToHtmlEntity($this->gEnv->getRootUrl() . '/'));
-				$this->tmpl->addVar("_widget", "sitename", $this->convertToDispString($this->gEnv->getSiteName()));
-
+				$navbarOptionClass = array();// 追加クラス
+				$menuAttr = $this->gEnv->getMenuAttr();
+								
 				// サイト名の表示制御
 				if (!$showSitename){
 					$sitenameOptionClass = ' visible-xs';			// モニタが最小サイズの場合のみ表示
 					$this->tmpl->addVar("_widget", "sitename_option_class", $sitenameOptionClass);
 				}
 				// 検索フィールド表示制御
-				if ($showSearch){
-					$this->tmpl->setAttribute('show_search', 'visibility', 'visible');
-				}
+				if ($showSearch) $this->tmpl->setAttribute('show_search', 'visibility', 'visible');
+
+				// 追加クラス
+				// メニュー属性を取得
+				if (!empty($menuAttr['bootstyle'])) $navbarOptionClass[] = $menuAttr['bootstyle'];
+				
 				// 別の色を指定の場合
-				if ($anotherColor){
-					$navbarOptionClass = ' navbar-inverse';
-					$this->tmpl->addVar("_widget", "navbar_option_class", $navbarOptionClass);
-				}
+				if ($anotherColor) $navbarOptionClass[] = 'navbar-inverse';
+
+				// データを画面に埋め込む
+				if (!empty($navbarOptionClass)) $this->tmpl->addVar("_widget", "navbar_option_class", ' ' . implode(' ', $navbarOptionClass));
+				$this->tmpl->addVar("_widget", "site_url", $this->convertUrlToHtmlEntity($this->gEnv->getRootUrl() . '/'));
+				$this->tmpl->addVar("_widget", "sitename", $this->convertToDispString($this->gEnv->getSiteName()));
 			}
 		} else {
 			// 出力抑止
@@ -443,11 +450,14 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 		$queryArray = array();
 		$parsedUrl = parse_url($url);
 		if (!empty($parsedUrl['query'])) parse_str($parsedUrl['query'], $queryArray);		// クエリーの解析
-		
+
 		// ルートかどうかチェック(クエリー文字列なし)
 		if ($this->isRootUrl($url)){
-			// ページサブIDで比較
-			if ($this->gEnv->getCurrentPageSubId() == $this->gEnv->getDefaultPageSubId()) return true;
+			$parsedUrl = parse_url($currentUrl);
+			if (empty($parsedUrl['query'])){		// クエリ文字列がないことが条件。「#」はあっても良い。
+				// ページサブIDで比較
+				if ($this->gEnv->getCurrentPageSubId() == $this->gEnv->getDefaultPageSubId()) return true;
+			}
 		}
 		
 		// パラメータがサブページIDだけの場合はページサブIDで比較
