@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_dropdown_menuWidgetContainer.php 2572 2009-11-19 01:19:56Z fishbone $
+ * @version    SVN: $Id: admin_dropdown_menuWidgetContainer.php 4945 2012-06-08 01:35:42Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -19,7 +19,6 @@ require_once($gEnvManager->getCurrentWidgetDbPath() . '/dropdown_menuDb.php');
 class admin_dropdown_menuWidgetContainer extends BaseAdminWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
-	private $sysDb;	// DB接続オブジェクト
 	private $serialNo;		// 選択中の項目のシリアル番号
 	private $serialArray = array();			// 表示中のシリアル番号
 	private $langId;
@@ -45,7 +44,6 @@ class admin_dropdown_menuWidgetContainer extends BaseAdminWidgetContainer
 		
 		// DBオブジェクト作成
 		$this->db = new dropdown_menuDb();
-		$this->sysDb = $this->gInstance->getSytemDbObject();
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -104,7 +102,6 @@ class admin_dropdown_menuWidgetContainer extends BaseAdminWidgetContainer
 		if (empty($this->configId)) $this->configId = $defConfigId;		// 呼び出しウィンドウから引き継いだ定義ID
 		$name	= $request->trimValueOf('item_name');			// ヘッダタイトル
 		$showTitle = ($request->trimValueOf('item_showtitle') == 'on') ? 1 : 0;		// タイトルを表示するかどうか
-		$limitUser = ($request->trimValueOf('item_limituser') == 'on') ? 1 : 0;		// ユーザを制限するかどうか
 		$this->menuType = $request->trimValueOf('item_menu_type');		// メニュータイプ
 		$this->menuId = $request->trimValueOf('item_menuid');
 		if ($this->menuId == '') $this->menuId = self::DEFAULT_MENU_ID;
@@ -127,7 +124,6 @@ class admin_dropdown_menuWidgetContainer extends BaseAdminWidgetContainer
 				$newObj->menuId	= $this->menuId;		// メニューID
 				$newObj->name	= $name;// 表示名
 				$newObj->showTitle = $showTitle;		// タイトルを表示するかどうか
-				$newObj->limitUser = $limitUser;		// ユーザを制限するかどうか
 				$newObj->menuType = $this->menuType;			// メニュータイプ
 				$newObj->cssId	= $this->cssId;					// CSS用ID
 				$newObj->css	= $this->css;					// メニューCSS
@@ -151,7 +147,6 @@ class admin_dropdown_menuWidgetContainer extends BaseAdminWidgetContainer
 				if ($ret){
 					// ウィジェットオブジェクト更新
 					$targetObj->showTitle = $showTitle;					// タイトルを表示するかどうか
-					$targetObj->limitUser = $limitUser;					// ユーザを制限するかどうか
 					//$targetObj->menuType = $this->menuType;			// メニュータイプは更新しない
 					$targetObj->cssId	= $this->cssId;					// CSS用ID
 					$targetObj->css		= $this->css;					// メニューCSS
@@ -188,7 +183,6 @@ class admin_dropdown_menuWidgetContainer extends BaseAdminWidgetContainer
 			$name = $this->createDefaultName();			// デフォルト登録項目名
 			$this->cssId = $this->createDefaultCssId();	// CSS用ID
 			$showTitle = 1;					// タイトルを表示するかどうか
-			$limitUser = 0;					// ユーザを制限するかどうか
 			
 			// デフォルト用のCSSを取得
 			$this->css = $this->getParsedTemplateData('default.tmpl.css', array($this, 'makeCss'));
@@ -200,7 +194,6 @@ class admin_dropdown_menuWidgetContainer extends BaseAdminWidgetContainer
 					$this->menuId	= $targetObj->menuId;		// メニューID
 					$name			= $targetObj->name;// 名前
 					$showTitle 		= $targetObj->showTitle;					// タイトルを表示するかどうか
-					$limitUser		= $targetObj->limitUser;					// ユーザを制限するかどうか
 					$this->menuType = $targetObj->menuType;			// メニュータイプ
 					$this->cssId	= $targetObj->cssId;					// CSS用ID
 					$this->css		= $targetObj->css;					// メニューCSS
@@ -224,9 +217,6 @@ class admin_dropdown_menuWidgetContainer extends BaseAdminWidgetContainer
 		$checked = '';
 		if ($showTitle) $checked = 'checked';
 		$this->tmpl->addVar("_widget", "show_title", $checked);	// タイトルを表示するかどうか
-		$checked = '';
-		if ($limitUser) $checked = 'checked';
-		$this->tmpl->addVar("_widget", "limit_user", $checked);	// ユーザを制限するかどうか
 		
 		// メニュークラスの設定
 		if (empty($this->menuType)){			// メニュータイプ(横型)
@@ -412,7 +402,7 @@ class admin_dropdown_menuWidgetContainer extends BaseAdminWidgetContainer
 			
 			$defCount = 0;
 			if (!empty($id)){
-				$defCount = $this->sysDb->getPageDefCount($this->gEnv->getCurrentWidgetId(), $id);
+				$defCount = $this->_db->getPageDefCount($this->gEnv->getCurrentWidgetId(), $id);
 			}
 			$operationDisagled = '';
 			if ($defCount > 0) $operationDisagled = 'disabled';
@@ -468,19 +458,22 @@ class admin_dropdown_menuWidgetContainer extends BaseAdminWidgetContainer
 						$option = 'target="_blank"';
 						break;
 				}
+				// メニュー項目を作成
+				$name = $this->getCurrentLangString($row['md_name']);
+				if (empty($name)) continue;
 				
 				// ##### ツリーメニュー作成 #####
 				if ($row['md_type'] == 0){	// リンク項目のとき
-					$treeHtml .= '<li><a href="' . $linkUrl . '" ' . $option . '>' . $this->convertToDispString($row['md_name']) . '</a></li>' . M3_NL;
+					$treeHtml .= '<li><a href="' . $linkUrl . '" ' . $option . '>' . $this->convertToDispString($name) . '</a></li>' . M3_NL;
 				} else if ($row['md_type'] == 1){			// フォルダのとき
 					// サブメニュー作成
-					$treeHtml .= '<li><a class="head" href="#">' . $this->convertToDispString($row['md_name']) . '</a>' . M3_NL;
+					$treeHtml .= '<li><a class="head" href="#">' . $this->convertToDispString($name) . '</a>' . M3_NL;
 					$treeHtml .= '<ul>' . M3_NL;
 					$treeHtml .= $this->createMenu($menuId, $row['md_id'], $level + 1);
 					$treeHtml .= '</ul>' . M3_NL;
 					$treeHtml .= '</li>' . M3_NL;
 				} else if ($row['md_type'] == 2){			// テキストのとき
-					//$treeHtml .= '<li><span>' . $this->convertToDispString($row['md_name']) . '</span></li>' . M3_NL;
+					//$treeHtml .= '<li><span>' . $this->convertToDispString($name) . '</span></li>' . M3_NL;
 				} else if ($row['md_type'] == 3){			// セパレータのとき
 					//$treeHtml .= '<li><span>' . '-----' . '</span></li>' . M3_NL;
 				}
